# Atanu MLKit

Welcome to the **Atanu MLKit**!


[![PyPI version](https://badge.fury.io/py/atanu-mlkit.svg)](https://badge.fury.io/py/atanu-mlkit)

#### Quick Installation
```bash
pip install atanu-mlkit
```




